package com.yizhi.live.application.controller;

import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.plugins.Page;
import com.baomidou.mybatisplus.toolkit.CollectionUtils;
import com.yizhi.application.orm.id.IdGenerator;
import com.yizhi.application.orm.util.QueryUtil;
import com.yizhi.core.application.context.ContextHolder;
import com.yizhi.core.application.context.RequestContext;
import com.yizhi.core.application.task.AbstractTaskHandler;
import com.yizhi.core.application.task.TaskExecutor;
import com.yizhi.core.application.vo.DroolsVo;
import com.yizhi.live.application.constant.UtilConstants;
import com.yizhi.live.application.domain.LiveActivity;
import com.yizhi.live.application.domain.LiveToken;
import com.yizhi.live.application.domain.ScopeAuthorization;
import com.yizhi.live.application.enums.LiveStatus;
import com.yizhi.live.application.service.ILiveActivityService;
import com.yizhi.live.application.service.ILiveTokenService;
import com.yizhi.live.application.service.IScopeAuthorizationService;
import com.yizhi.live.application.util.LiveEvenSendMessage;
import com.yizhi.live.application.vo.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;
import java.util.stream.Collectors;

@Api(tags = "直播接口")
@RestController
@RequestMapping("/manage/live")
public class LiveController {

    private static final Logger LOG = LoggerFactory.getLogger(LiveController.class);

    @Autowired
    ILiveActivityService liveActivityService;

    @Autowired
    IdGenerator idGenerator;

    @Autowired
    ILiveTokenService liveTokenService;

    @Autowired
    IScopeAuthorizationService scopeAuthorizationService;
    @Autowired
    private TaskExecutor taskExecutor;
    @Autowired
    private LiveEvenSendMessage liveEvenSendMessage;

    @GetMapping("/channelNo/get")
    public String getChannelNo(@RequestParam("id") Long id) {

        LiveActivity liveActivity = liveActivityService.selectById(id);
        if (liveActivity != null) {
            return liveActivity.getChannel();
        }
        return "";
    }

    @PostMapping("/save")
    public Boolean save(
            @RequestBody LiveActivityResultVO liveActivityResultVO
    ) {
        return liveActivityService.saveLive(liveActivityResultVO);
    }


    @PostMapping("/update")
    public Boolean update(
            @RequestBody LiveActivityResultVO liveActivityResultVO
    ) {
        return liveActivityService.updateLive(liveActivityResultVO);
    }

    /**
     * 管理端 直播列表查询
     *
     * @param title     主题
     * @param companyId 企业id
     * @param siteId    站点id
     * @param orgIds    管辖区id
     * @param pageNo    分页的页数
     * @param pageSize  分页的条数
     * @return PageLiveVo 前台展示对象
     */
    @GetMapping("/list")
    public Page<PageLiveVo> list(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "startTimeString", required = false) String startTimeString,
            @RequestParam(name = "endTimeString", required = false) String endTimeString,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "orgIds", required = false) List<Long> orgIds,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize,
            @RequestParam(name = "expTimeString", required = false) String expTimeString,
            @RequestParam(name = "status", required = false) Integer status,
            @RequestParam(name = "viewType", required = false) Integer viewType,
            @RequestParam(name = "startTimeAsc",required = false) Boolean startTimeAsc,
            @RequestParam(name = "endTimeAsc",required = false) Boolean endTimeAsc
    ) {

        Page<PageLiveVo> liveActivityPage = liveActivityService.searchPage(title, startTimeString,
                endTimeString, companyId, siteId, orgIds,
                pageNo, pageSize, expTimeString, status, viewType,null,null);
        return liveActivityPage;
    }


    /**
     * 管理端 直播列表查询
     * 新增根据时间排序功能
     *
     * @param title     主题
     * @param companyId 企业id
     * @param siteId    站点id
     * @param orgIds    管辖区id
     * @param pageNo    分页的页数
     * @param pageSize  分页的条数
     * @param startTimeAsc 按照开始时间排序 当开始和结束时间排序都不传递的时候；默认按照创建时间倒叙；
     * @param endTimeAsc 按照结束时间排序；
     * @return PageLiveVo 前台展示对象
     */
    @GetMapping("/v2/list")
    public Page<PageLiveVo> listV2(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "startTimeString", required = false) String startTimeString,
            @RequestParam(name = "endTimeString", required = false) String endTimeString,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "orgIds", required = false) List<Long> orgIds,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize,
            @RequestParam(name = "expTimeString", required = false) String expTimeString,
            @RequestParam(name = "status", required = false) Integer status,
            @RequestParam(name = "viewType", required = false) Integer viewType,
            @RequestParam(name = "startTimeAsc",required = false) Boolean startTimeAsc,
            @RequestParam(name = "endTimeAsc",required = false) Boolean endTimeAsc
    ) {

        Page<PageLiveVo> liveActivityPage = liveActivityService.searchPage(title, startTimeString,
                endTimeString, companyId, siteId, orgIds,
                pageNo, pageSize, expTimeString, status, viewType,startTimeAsc,endTimeAsc);
        return liveActivityPage;
    }

    /**
     * 查询近7天的已完成的直播（包含今天的）
     *
     * @return
     */
    @GetMapping("/sevenDays/get")
    public List<LiveActivity> findWithinSevenDaysLive() {
        RequestContext rt = ContextHolder.get();
        return liveActivityService.findWithinSevenDaysLive(rt.getCompanyId(), rt.getSiteId(), rt.getAccountId());
    }

    @GetMapping("/portal/list")
    public List<PageLiveVo> portalList(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "startTime", required = false) Date startTime,
            @RequestParam(name = "endTime", required = false) Date endTime,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "orgIds", required = false) List<Long> orgIds,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize
    ) {
        List<PageLiveVo> pageLiveVoList = liveActivityService.portalList(title, startTime,
                endTime, companyId, siteId, orgIds,
                pageNo, pageSize);
        return pageLiveVoList;
    }

    @GetMapping("/portal/v2/list")
    public Page<PageLiveVo> portalListV2(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "startTime", required = false) Date startTime,
            @RequestParam(name = "endTime", required = false) Date endTime,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "orgIds", required = false) List<Long> orgIds,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize
    ) {
        Page<PageLiveVo> pageLiveVoList = liveActivityService.portalList2(title, startTime,
                endTime, companyId, siteId, orgIds,
                pageNo, pageSize);
        return pageLiveVoList;
    }


    @PostMapping("/delete")
    public Boolean delete(
            @RequestBody LiveActivity liveActivity
    ) {
        LiveActivity liveActivity1 = liveActivityService.selectById(liveActivity.getId());
        Boolean f = liveActivityService.deleteChanel(liveActivity1.getChannel());
        if (f) {
            Boolean t = liveActivityService.deleteById(liveActivity.getId());
            return t;
        }
        return f;
    }

    @GetMapping("/get")
    public LiveActivityResultVO list(@RequestParam("id") Long id) {
        LiveActivityResultVO liveActivityResultVO = new LiveActivityResultVO();
        LiveActivity liveActivity = liveActivityService.selectById(id);
        ScopeAuthorization scopeAuthorization = new ScopeAuthorization();
        scopeAuthorization.setLiveId(id);
        EntityWrapper<ScopeAuthorization> wrapper = new EntityWrapper<ScopeAuthorization>(scopeAuthorization);
        LiveActivityVO liveactivityvo = new LiveActivityVO();
        BeanUtils.copyProperties(liveActivity, liveactivityvo);
        liveActivityResultVO.setLiveActivity(liveactivityvo);

        List<ScopeAuthorization> scopeAuthorizations = scopeAuthorizationService.selectList(wrapper);
        List<ScopeAuthorizationVO> scopeauthorizations = new ArrayList<>();
        for (ScopeAuthorization authorization : scopeAuthorizations) {
            ScopeAuthorizationVO scopeauthorizationvo = new ScopeAuthorizationVO();
            BeanUtils.copyProperties(authorization, scopeauthorizationvo);
            scopeauthorizations.add(scopeauthorizationvo);
        }
        liveActivityResultVO.setScopeAuthorizations(scopeauthorizations);
        return liveActivityResultVO;
    }

    @GetMapping("/getLive")
    public LiveActivity getLive(@RequestParam("id") Long id) {
        return liveActivityService.selectById(id);
    }


    @PostMapping("/token")
    public String getToken(@RequestBody LiveTokenVo liveTokenVo) {
        String token = liveActivityService.setToken(liveTokenVo.getChannel());
        if ("error".equals(token)) {
            return token;
        }
        LiveToken liveTokenVO = new LiveToken();
        liveTokenVO.setId(idGenerator.generate());
        liveTokenVO.setCreateById(liveTokenVo.getCreateById());
        liveTokenVO.setCreateByName(liveTokenVo.getCreateByName());
        liveTokenVO.setToken(token);

        LiveToken lt = new LiveToken();
        BeanUtils.copyProperties(lt, liveTokenVO);
        liveTokenService.insert(lt);
        return token;
    }

    @PostMapping("/signature")
    public LiveAppIdVo signature() {
        LiveAppIdVo liveAppIdVo = new LiveAppIdVo();
        liveAppIdVo.setAppId(UtilConstants.APP_ID);
        liveAppIdVo.setAppSecret(UtilConstants.APP_SECRET);
        return liveAppIdVo;
    }

    @GetMapping("/api/list")
    public List<PageLiveVo> apiList(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "ids", required = false) List<Long> ids,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize
    ) {
        List<PageLiveVo> list = liveActivityService.apiSearchHomeList(ids, title, companyId,
                siteId, pageNo, pageSize);
        return list;
    }


    @GetMapping("/api/pageList")
    public Page<PageLiveVo> apiPageList(
            @RequestParam(name = "title", required = false) String title,
            @RequestParam(name = "companyId", required = false) Long companyId,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "ids", required = false) List<Long> ids,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize
    ) {
        Page<PageLiveVo> page = liveActivityService.apiSearchPageList(ids, title, companyId,
                siteId, pageNo, pageSize);
        return page;
    }


    /**
     * 直播指定范围保存
     *
     * @param scopeAuthorizations
     * @return
     */
    @PostMapping("/scopeAuthorization/save")
    public boolean saveCoursrAccount(@RequestBody List<ScopeAuthorization> scopeAuthorizations) {
        Boolean f = scopeAuthorizationService.insertList(scopeAuthorizations);
        return f;
    }

    /**
     * 直播指定范围保存，不删除之前的记录
     *
     * @param scopeAuthorizations
     * @return
     */
    @PostMapping("/scopeAuthorization/insert")
    Boolean insertScopeAuthorization(@RequestBody List<ScopeAuthorization> scopeAuthorizations) {
        return scopeAuthorizationService.insertAllList(scopeAuthorizations);
    }


    /**
     * 已保存的指定范围集合
     *
     * @param liveId
     * @return
     */
    @GetMapping("/scopeAuthorization/list")
    public List<ScopeAuthorization> getCourseAccountList(@RequestParam(name = "liveId") Long liveId) {
        ScopeAuthorization scopeAuthorization = new ScopeAuthorization();
        scopeAuthorization.setLiveId(liveId);
        EntityWrapper<ScopeAuthorization> wrapper = new EntityWrapper<ScopeAuthorization>(scopeAuthorization);
        List<ScopeAuthorization> scopeAuthorizations = scopeAuthorizationService.selectList(wrapper);
        return scopeAuthorizations;
    }


    /**
     * 直播上架
     *
     * @param param 带id
     * @return
     */
    @PostMapping("/up")
    public Boolean up(@RequestBody LiveActivity param) {
        LiveActivity liveActivity = liveActivityService.selectById(param.getId());
        if (liveActivity != null) {
            liveActivity.setShelves(1);
            boolean b = liveActivityService.updateById(liveActivity);
            if (b) {
                updateStatus(liveActivity, ContextHolder.get());
            }
            return b;
        }
        return Boolean.FALSE;
    }

    /**
     * 直播下架
     *
     * @param param 只带id
     * @return
     */
    @PostMapping("/down")
    public Boolean down(@RequestBody LiveActivity param) {
        LiveActivity liveActivity = liveActivityService.selectById(param.getId());
        if (liveActivity != null) {
            liveActivity.setShelves(0);
            boolean b = liveActivityService.updateById(liveActivity);
            if (b) {
                updateStatus(liveActivity, ContextHolder.get());
            }
            return b;
        }
        return Boolean.FALSE;
    }

    /**
     * 发消息告知业务状态改变
     *
     * @param liveActivity
     * @param context
     */
    public void updateStatus(LiveActivity liveActivity, RequestContext context) {
        try { //发消息告知业务状态有变化
            if (liveActivity != null) {
                if (liveActivity.getEnableRemind() == 1) {
                    MessageRemindVo remindVo = new MessageRemindVo();
                    remindVo.setTaskStatusUpdate(true);
                    taskExecutor.asynExecute(new AbstractTaskHandler() {
                        @Override
                        public void handle() {
                            liveEvenSendMessage.systemSendMessage(liveActivity, remindVo, context);
                        }
                    });
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 根据频道id获得直播信息
     */
    @GetMapping("/channelId/view")
    public LiveActivity viewByChannelId(@RequestParam(name = "channelId") String channelId) {
        LiveActivity liveActivity = new LiveActivity();
        liveActivity.setChannel(channelId);
        EntityWrapper<LiveActivity> entityWrapper = new EntityWrapper<>(liveActivity);
        return liveActivityService.selectOne(entityWrapper);
    }


    @ApiOperation(value = "可见范围导出", notes = "可见范围导出")
    @GetMapping("/export/visiblRange")
    public VisibleRangeExport vsibleRangeExport(@ApiParam(value = "直播的Id", name = "直播的Id", required = true) @RequestParam(name = "liveId", required = true) Long liveId) {
        return liveActivityService.vsibleRangeExport(liveId);
    }


    @ApiOperation(value = "可见范围导出", notes = "可见范围导出")
    @PostMapping("/access/lives")
    public List<Long> accessLives(@RequestBody AccessLiveVO vo) {
        EntityWrapper<ScopeAuthorization> ew = QueryUtil.condition(new ScopeAuthorization());
        List<Long> ids = new ArrayList<>();
        List<Long> orgIds = vo.getOrgIds();
        if (CollectionUtils.isNotEmpty(orgIds)) {
            ids.addAll(orgIds);
        }
        List<Long> userIds = vo.getUserIds();
        if (CollectionUtils.isNotEmpty(userIds)) {
            ids.addAll(userIds);
        }
        List<Long> liveIds = vo.getLiveIds();
        if (ids.size() == 0 || CollectionUtils.isEmpty(liveIds)) {
            return null;
        }

        ew.in("site_id", ids).in("live_id", liveIds);

        List<ScopeAuthorization> data = scopeAuthorizationService.selectList(ew);
        if (data == null || data.size() == 0) {
            return null;
        }

        EntityWrapper<LiveActivity> ewLive = QueryUtil.condition(new LiveActivity());
        ewLive.in("id", liveIds).eq("scope", 0);
        List<LiveActivity> liveActivitys = liveActivityService.selectList(ewLive);
        List<Long> retLiveIds = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(liveActivitys)) {
            retLiveIds = liveActivitys.stream().map(obj -> obj.getId()).collect(Collectors.toList());
        }

        List<Long> selectLives = data.stream().map(obj -> obj.getLiveId()).collect(Collectors.toList());
        if (CollectionUtils.isNotEmpty(selectLives)) {
            retLiveIds.addAll(selectLives);
        }

        return selectLives;
    }

    /**
     * PC端  分页查询直播列表
     *
     * @param title
     * @param ids
     * @param pageNo
     * @param pageSize
     * @return
     */
    @GetMapping("/pc/pageList")
    public Page<PageLiveVo> pcPageList(@RequestParam(name = "title", required = false) String title,
                                       @RequestParam(name = "ids", required = false) List<Long> ids,
                                       @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                       @RequestParam(name = "pageSize", defaultValue = "20") Integer pageSize) {
        RequestContext context = ContextHolder.get();
        List idList = new ArrayList();
        if (null != ids && ids.size() > 0) {
            idList.addAll(ids);
        } else {
            idList.addAll(context.getRelationIds());
            System.out.println("relationIds:" + context.getRelationIds());
        }
        Page<PageLiveVo> page = liveActivityService.pcSearchPageList(idList, title, context.getCompanyId(), context.getSiteId(), pageNo, pageSize);
        List<PageLiveVo> list = page.getRecords();
        if (CollectionUtils.isNotEmpty(list)) {
            //按开始时间倒序
            Collections.sort(list, new Comparator<PageLiveVo>() {
                @Override
                public int compare(PageLiveVo o1, PageLiveVo o2) {
                    Long diff = o2.getStartTime().getTime() - o1.getStartTime().getTime();
                    if (diff > 0) {
                        return 1;
                    } else if (diff < 0) {
                        return -1;
                    }
                    return 0;
                }
            });
            Long currentTime = System.currentTimeMillis();
            List<PageLiveVo> allList = new ArrayList<>();
            List<PageLiveVo> liveList = new ArrayList<>();
            List<PageLiveVo> notStartList = new ArrayList<>();
            List<PageLiveVo> endList = new ArrayList<>();

            //按状态 直播中》即将开始》直播结束   相同状态按 开始时间倒序

            for (PageLiveVo vo : list) {
                if (LiveStatus.LIVE.getName().equals(vo.getStatus())) {
                    liveList.add(vo);
                } else if (LiveStatus.NOT_START.getName().equals(vo.getStatus())) {
                    notStartList.add(vo);
                } else {
                    endList.add(vo);
                }
            }

            allList.addAll(liveList);
            allList.addAll(notStartList);
            allList.addAll(endList);
            page.setRecords(allList);
        }
        return page;
    }

    /**
     * 根据站点Id查询直播列表
     *
     * @param siteId
     * @param pageNo
     * @param pageSize
     * @return
     */
    @GetMapping("/pc/getPage")
    public Page<PageLiveVo> getPageLiveVoList(@RequestParam(name = "siteId", required = false) Long siteId,
                                              @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                              @RequestParam(name = "pageSize", defaultValue = "15") Integer pageSize) {
        Page<PageLiveVo> pageLiveVos = liveActivityService.getPageLiveVoList(siteId, pageNo, pageSize);


        if (pageLiveVos == null && pageLiveVos.getSize() == 0) {
            return null;
        }
        return pageLiveVos;
    }


    @GetMapping("/pc/getPage/notIds")
    public Page<LiveActivity> getPageLiveVoListNotIds(
            @RequestParam(name = "ids", required = false) List<Long> ids,
            @RequestParam(name = "siteId", required = false) Long siteId,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "15") Integer pageSize) {
        return liveActivityService.getPageLiveVoListNotIds(ids, siteId, pageNo, pageSize);

    }

    /**
     * 根据relationId 判断这个人是否可以看到这这场直播
     *
     * @param relationId 里面有accountId or orgId
     * @param liveId     直播Id
     * @return
     */
    @GetMapping("pc/judgeScope")
    public Boolean judgeScope(@RequestParam(name = "relationId", required = false) List<Long> relationId,
                              @RequestParam(name = "liveId", required = false) Long liveId) {
        Boolean flag = liveActivityService.judgeScope(relationId, liveId);
        return flag;
    }

    /**
     * 根据直播Id查看直播信息
     *
     * @param liveId
     * @return
     */
    @GetMapping("pc/queryLive")
    public LiveActivity queryLive(@RequestParam(name = "liveId") Long liveId) {
        if (null != liveId) {
            return liveActivityService.selectById(liveId);
        }
        return null;
    }

    @GetMapping("/pc/queryLive/byIds")
    public Page<LiveActivity> LiveActivityByIds(
            @RequestParam(value = "listIds", required = false) List<Long> listIds,
            @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
            @RequestParam(name = "pageSize", defaultValue = "15") Integer pageSize) {
        return liveActivityService.LiveActivityByIds(listIds, pageNo, pageSize);
    }

    /**
     * 根据传入的频道Id,返回直播状态
     *
     * @param channelId
     * @return
     */
    @GetMapping("/pc/getLiveStatus")
    public Integer getLiveStatus(@ApiParam(value = "channelId 频道Id") @RequestParam(value = "channelId") String channelId) {
        if (StringUtils.isNotBlank(channelId)) {
            return liveActivityService.getLiveStatus(channelId);
        }
        return -1;
    }

    /**
     * 根据传入的relationIds 里面有accountId、orgId
     *
     * @param relationIds
     * @param pageNo
     * @param pageSize
     * @return
     */
    @PostMapping("/pc/queryLiveListByRelationIds")
    public List<PageLiveVo> queryLiveListByRelationIds(@ApiParam(value = "relationIds 里面有accountId、orgId")
                                                       @RequestParam(value = "relationIds 里面有accountId、orgId", required = false) List<Long> relationIds,
                                                       @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                       @RequestParam(name = "pageSize", defaultValue = "15") Integer pageSize) {

        return liveActivityService.queryLiveListByRelationIds(relationIds, pageNo, pageSize);
    }


    @GetMapping(value = "/by/new/server")
    public List<Map<String, Object>> getServerByCompanyIdAndIds(@RequestParam("companyId") Long companyId, @RequestParam(value = "ids", required = false) List<Long> ids) {
        return liveActivityService.getServerByCompanyIdAndIds(companyId, ids);
    }

    @PostMapping("/getPageToCalendar")
    public Page<PageLiveVo> getPageToCalendar(@ApiParam("paramVo") @RequestBody CalendarTaskParamVo paramVo) {
        Page<PageLiveVo> page = new Page(paramVo.getPageNo(), paramVo.getPageSize());

        return liveActivityService.getPageToCalendar(paramVo.getDate(), page);
    }

    @GetMapping("/getPageByDrools")
    Page<DroolsVo> getPageByDrools(@RequestParam("field") String field,
                                   @RequestParam(value = "value", required = false) String value,
                                   @RequestParam("pageNo") Integer pageNo,
                                   @RequestParam("pageSize") Integer pageSize) {
        Page<DroolsVo> page = new Page<>(pageNo, pageSize);
        return liveActivityService.getPageByDrools(field, value, page);
    }


}
