package com.yizhi.live.application.domain;

import com.baomidou.mybatisplus.activerecord.Model;
import com.baomidou.mybatisplus.annotations.TableField;
import com.baomidou.mybatisplus.annotations.TableLogic;
import com.baomidou.mybatisplus.annotations.TableName;
import com.baomidou.mybatisplus.enums.FieldFill;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * <p>
 * 直播活动表
 * </p>
 *
 * @author fulan123
 * @since 2018-04-10
 */
@Data
@Api(tags = "LiveActivity", description = "直播活动表")
@TableName("live_activity")
public class LiveActivity extends Model<LiveActivity> {

    private static final long serialVersionUID = 1L;


    @ApiModelProperty(value = "主键")
    private Long id;

    @ApiModelProperty(value = "直播主题")
    private String title;

    @ApiModelProperty(value = "直播密码")
    private String password;

    @ApiModelProperty(value = "直播logo")
    @TableField("logo_image")
    private String logoImage;

    @ApiModelProperty(value = "主播名称")
    private String anchor;

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @ApiModelProperty(value = "开始时间")
    @TableField("start_time")
    private Date startTime;

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @ApiModelProperty(value = "结束时间")
    @TableField("end_time")
    private Date endTime;

    @ApiModelProperty(value = "直播介绍")
    private String description;

    @ApiModelProperty(value = "可见范围 0 为站点 1 为可选范围")
    private Integer scope;

    @ApiModelProperty(value = "频道号")
    private String channel;

    @ApiModelProperty(value = "是否启用提醒 1:启用 0：关闭")
    @TableField("enable_remind")
    private Integer enableRemind;

    @TableField(value = "create_by_id", fill = FieldFill.INSERT)
    private Long createById;

    @TableField(value = "create_by_name", fill = FieldFill.INSERT)
    private String createByName;

    @TableField(value = "create_time", fill = FieldFill.INSERT)
    private Date createTime;

    @ApiModelProperty(value = "企业")
    @TableField("company_id")
    private Long companyId;

    @TableField("org_id")
    private Long orgId;

    @TableField("site_id")
    private Long siteId;

    @ApiModelProperty(value = "0 未上架 1 已上架  2 草稿")
    private Integer shelves;

    @ApiModelProperty(value = "secretKey")
    @TableField("secret_key")
    private String secretKey;

    @ApiModelProperty(value = "keywords")
    @TableField("keywords")
    private String keywords;

    @ApiModelProperty(value = "是否启用在日历任务中显示")
    @TableField("enable_task")
    private Integer enableTask;

    @ApiModelProperty(value = "直播场景：alone: 活动拍摄 ; ppt: 三分屏; topclass: 大班课")
    @TableField("scene")
    private String scene;

    @ApiModelProperty(value = "观看类型：0: 公开播放 ; 1: 站内授权播放; ")
    @TableField("view_type")
    private Integer viewType;

    @TableLogic
    @TableField("deleted")
    private Integer deleted;

    @ApiModelProperty(value = "排序")
    @TableField("sort")
    private Integer sort;

    @ApiModelProperty(value = "直播状态 10:未开始 40:直播中 90:已结束")
    @TableField("status")
    private Integer status;

    @ApiModelProperty(value = "直播回放开关状态 1: 开 0:关闭")
    @TableField("replay_status")
    private Boolean replayStatus;

    @ApiModelProperty(value = "直播回放回调状态 1:已回调 0:未回调")
    @TableField("replay_callback_status")
    private Boolean replayCallbackStatus;

    @Override
    protected Serializable pkVal() {
        return this.id;
    }

    @Override
    public String toString() {
        return "LiveActivity{" +
                "id=" + id +
                ", title='" + title + '\'' +
                ", password='" + password + '\'' +
                ", logoImage='" + logoImage + '\'' +
                ", anchor='" + anchor + '\'' +
                ", startTime=" + startTime +
                ", endTime=" + endTime +
                ", description='" + description + '\'' +
                ", scope=" + scope +
                ", channel='" + channel + '\'' +
                ", createById=" + createById +
                ", createByName='" + createByName + '\'' +
                ", createTime=" + createTime +
                ", companyId=" + companyId +
                ", orgId=" + orgId +
                ", siteId=" + siteId +
                ", shelves=" + shelves +
                ", secretKey='" + secretKey + '\'' +
                '}';
    }
}
