package com.yizhi.live.application.jobhandler;

import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.yizhi.application.orm.id.IdGenerator;
import com.yizhi.live.application.domain.LiveActivity;
import com.yizhi.live.application.domain.LiveReplay;
import com.yizhi.live.application.service.ILiveActivityService;
import com.yizhi.live.application.service.ILiveReplayService;
import com.yizhi.live.application.util.PolyvUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @Date 2020/12/8 2:22 下午
 * @Author lvjianhui
 **/
@RestController
@RequestMapping("/job/live")
public class PolyvReplayLogHandler {

    @Autowired
    private ILiveActivityService iLiveActivityService;
    @Autowired
    private ILiveReplayService iLiveReplayService;
    @Autowired
    IdGenerator idGenerator;
    private Logger logger = LoggerFactory.getLogger(PolyvReplayLogHandler.class);

    @GetMapping("/insert/replay")
    public void insertLiveReplay() {
        Date currencyDate = new Date();
        List<LiveActivity> allLive = getAllLive();
        logger.trace("直播数量为:{}", allLive.size());
        allLive.stream().forEach(live -> {
            List<LiveReplay> list = new ArrayList<>();
            try {
                list = PolyvUtils.getChannelReplay(live.getChannel());
            } catch (Exception e) {
                logger.error("查询视频回放出错", e);
                return;
            }
            logger.trace("查询视频回放 :{}", list.size());
            list.stream().forEach(replay -> {
                LiveReplay liveReplay = iLiveReplayService.getByVideoPoolId(replay.getVideoPoolId());
                if (null == liveReplay) {
                    replay.setId(idGenerator.generate());
                    replay.setChannelId(live.getChannel());
                    replay.setLiveId(live.getId());
                    replay.setLivePlanStartAt(live.getStartTime());
                    replay.setLiveLogoUrl(live.getLogoImage());
                    replay.setLiveAnchor(live.getAnchor());
                    replay.setCompanyId(live.getCompanyId());
                    replay.setSiteId(live.getSiteId());
                    try {
                        iLiveReplayService.insert(replay);
                    } catch (Exception e) {
                        logger.error("新增视频回放出错", e);
                    }
                }else {
                    liveReplay.setTitle(replay.getTitle());
                    liveReplay.setUpdatedAt(currencyDate);
                    iLiveReplayService.updateById(liveReplay);
                }
            });

        });

        // 更新时间小于当前时间，证明已再保利威删除，故直接删除
        iLiveReplayService.deleteByUpdateTime(new Date(currencyDate.getTime() - 5 * 60 * 1000));
    }

    private List<LiveActivity> getAllLive() {
        LiveActivity liveActivity = new LiveActivity();
        liveActivity.setDeleted(0);
        EntityWrapper<LiveActivity> entityWrapper = new EntityWrapper<>(liveActivity);
        return iLiveActivityService.selectList(entityWrapper);
    }

}
